@@ -332,6 +332,8 @@ class DocumentHelper(Signals):
         geom = window.get_geometry()
         #FIXME: there should be some override in pygobject to create the rectangle with values
         rect = Gdk.Rectangle()
+        rect.x = 0
+        rect.y = 0
         rect.width = geom[2]
         rect.height = geom[3]
         window.invalidate_rect(rect, False)
@@ -655,8 +657,7 @@ class DocumentHelper(Signals):
         buf = self._buffer
 
         layout = self._view.create_pango_layout('W')
-        #FIXME
-        width = layout.get_pixel_extents()[1][2]
+        width = layout.get_pixel_extents()[1].width
 
         context = self._view.get_style_context()
         col = context.get_background_color(Gtk.StateFlags.SELECTED)
@@ -808,6 +809,8 @@ class DocumentHelper(Signals):
 
         if hasattr(where, 'assign'):
             where.assign(iterwas)
+        elif hasattr(Gedit, 'utils_text_iter_assign'):
+            Gedit.utils_text_iter_assign(where, iterwas)
 
         if atinsert:
             buf.move_mark(buf.get_insert(), iterwas)
@@ -902,6 +905,9 @@ class DocumentHelper(Signals):
                 if hasattr(start, 'assign'):
                     start.assign(piter)
                     end.assign(piter)
+                elif hasattr(Gedit, 'utils_text_iter_assign'):
+                    Gedit.utils_text_iter_assign(start, piter)
+                    Gedit.utils_text_iter_assign(end, piter)
             else:
                 self.remove_edit_points()
 
@@ -1303,61 +1309,52 @@ class DocumentHelper(Signals):
         tooltip.set_custom(table)
         return True
 
-    def _background_color(self):
+    def get_border_color(self):
         context = self._view.get_style_context()
-        col = context.get_background_color(context.get_state())
-        if col.green > 0.8:
-            col.green -= 0.2
-        else:
-            col.green += 0.2
+        color = context.get_background_color(Gtk.StateFlags.NORMAL).copy()
 
-        return col
+        color.red = 1 - color.red
+        color.green = 1 - color.green
+        color.blue = 1 - color.blue
+        color.alpha = 0.5
+
+        return color
 
     def on_view_draw(self, view, cr):
         window = view.get_window(Gtk.TextWindowType.TEXT)
+
         if Gtk.cairo_should_draw_window (cr, window):
             return self._draw_column_mode(cr)
 
         window = view.get_window(Gtk.TextWindowType.TOP)
+
         if window is None or not Gtk.cairo_should_draw_window (cr, window):
             return False
 
         if not self._in_mode:
             return False
 
-        col = self._background_color()
-
-        Gdk.cairo_set_source_rgba(cr, col)
-        cr.fill_preserve()
-
         layout = view.create_pango_layout(_('Multi Edit Mode'))
-
-        layout.set_font_description(Pango.FontDescription('Sans 10'))
-        #FIXME extens do not work
         extents = layout.get_pixel_extents()
 
         w = window.get_width()
         h = window.get_height()
 
-        Gtk.cairo_transform_to_window (cr, view, window)
+        Gtk.cairo_transform_to_window(cr, view, window)
 
         cr.translate(0.5, 0.5)
         cr.set_line_width(1)
 
-        context = view.get_style_context()
-        col = context.get_color(context.get_state())
-        col.alpha = 0.6
+        col = self.get_border_color()
         Gdk.cairo_set_source_rgba(cr, col)
 
         cr.move_to(0, h - 1)
         cr.rel_line_to(w, 0)
         cr.stroke()
 
-        col.alpha = 1.0
-        Gdk.cairo_set_source_rgba(cr, col)
-        #FIXME: can't we use the x, y from the top window to place the text?
-        #cr.move_to(w - extents[1][2] - 3, (h - extents[1][3]) / 2)
-        cr.move_to(w - 3, h / 2)
+        context = self._view.get_style_context()
+        Gdk.cairo_set_source_rgba(cr, context.get_color(Gtk.StateFlags.NORMAL))
+        cr.move_to(w - extents[1].width - 3, (h - extents[1].height) / 2)
         PangoCairo.show_layout(cr, layout)
 
         if not self._status:
@@ -1368,9 +1365,7 @@ class DocumentHelper(Signals):
         if status:
             layout.set_markup(status, -1)
 
-            #FIXME
-            #cr.move_to(3, (h - extents[1][3]) / 2)
-            cr.move_to(3, h / 2)
+            cr.move_to(3, (h - extents[1].height) / 2)
             PangoCairo.show_layout(cr, layout)
 
         return False
